@@ -12,8 +12,12 @@
 
 #include "knewstuffcore_export.h"
 
+#include <memory>
+
 namespace KNSCore
 {
+class Entry;
+class QuestionPrivate;
 /**
  * @short A way to ask a user a question from inside a GUI-less library (like KNewStuffCore)
  *
@@ -33,6 +37,7 @@ Question question(Question::SelectFromListQuestion);
 question.setTitle("Pick your option");
 question.setQuestion("Please select which option you would like");
 question.setList(choices);
+question.setEntry(entry);
 if(question.ask() == Question::OKResponse) {
     QString theChoice = question.response();
 }
@@ -62,7 +67,7 @@ public:
     Q_ENUM(QuestionType)
 
     explicit Question(QuestionType = YesNoQuestion, QObject *parent = nullptr);
-    virtual ~Question();
+    ~Question() override;
 
     Response ask();
 
@@ -75,6 +80,8 @@ public:
     QString title() const;
     void setList(const QStringList &newList);
     QStringList list() const;
+    void setEntry(const Entry &entry);
+    Entry entry() const;
 
     /**
      * When the user makes a choice on a question, that is a response. This is the return value in ask().
@@ -89,10 +96,10 @@ public:
      */
     void setResponse(const QString &response);
     QString response() const;
+
 private:
-    class Private;
-    Private* d;
+    const std::unique_ptr<QuestionPrivate> d;
 };
 }
 
-#endif//KNS3_QUESTION_H
+#endif // KNS3_QUESTION_H
